% BUILDC Compile all C code.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield


% Preserve current working directory
storedpath = pwd;

% Change to the directory where this code is located
cd(fileparts(mfilename('fullpath')))

% Try to compile:
try

    % Clean binaries
    delete bin/*.obj
    delete bin/*.o
    
    % Compile sliding window DFT
    disp('Compiling swdft.c [Sliding Window DFT] ...');
    mex -c -outdir bin -Isrc src/swdft.c

    % Compile ZCPA algorithm
    disp('Compiling zcpa.c [Zero Crossings/Peak Amplitudes] ...');
    mex -c -outdir bin -Isrc src/zcpa.c

    % Compile IFRH algorithm
    disp('Compiling ifrh.c [Instantaneous Frequency Histogram] ...');
    mex -c -outdir bin -Isrc src/ifrh.c

    % Compile succeeded: Print a happy message
    disp('Done.');

catch %#ok

    % Compile failed: Print an error message
    error('Could not compile code base.');

end

% Restore working directory
cd(storedpath);

% end of file %
