/* swdft.h */

/* Code to produce sliding-window discrete Fourier transform.
 * Author: Robert Mill <rob.mill.uk@gmail.com>
 * (C)2015 University of Sheffield
 */

#ifndef SWDFT_H_INCLUDED
#define SWDFT_H_INCLUDED


/* MACRO DEFINITIONS */

/* Success and failure constants */
#define SWD_SUCCESS 0
#define SWD_FAILURE 1

#ifndef M_PI
    #define M_PI 3.1415926535897932385
#endif

/* STRUCTURE DEFINITIONS */

/* Structure to store SWDFT options */
struct SWD_Options
{
    int n_dft_len;     /* length of DFT (samples) */
    int n_cell_start;  /* first DFT cell */
    int n_cell_count;  /* number of cells */
    int n_fwin_len;    /* length of frequency domain window (in cells) */
    int n_fringe;      /* cells in fringe for f.d. windowing */

    double d_leak;  /* optional leak on phasor */

    const double *dp_fwin_re;  /* real frequency domain coefficients */
    const double *dp_fwin_im;  /* imag frequency domain coefficients */
};


/* Structure to store SWDFT state */
struct SWD_State
{
    int n_buf_pos;  /* position in recent sample buffer */

    double *dp_buffer;    /* buffer storing recent samples */
    double *dp_cells_re;  /* real DFT cells */
    double *dp_cells_im;  /* imag DFT cells */
    double *dp_filt_re;   /* real part of filter for cell */
    double *dp_filt_im;   /* imag part of filter for cell */
};


/* TYPE DEFINITIONS */

typedef struct SWD_State SWD_State;

typedef struct SWD_Options SWD_Options;


/* FUNCTION PROTOTYPES */

void SWD_InitOptions( SWD_Options *sp_opt );

int SWD_AllocState( SWD_State *sp_state, const SWD_Options *sp_opt );

void SWD_FreeState( SWD_State *sp_state );

void SWD_InitState( SWD_State *sp_state, const SWD_Options *sp_opt );

void SWD_Run(
    const double *dp_in,
    double *dp_out_re,
    double *dp_out_im,
    int n_in,
    SWD_State *sp_state,
    const SWD_Options *sp_opt );

#endif

/* end of file */
