function opt = ifrh_opt
% IFRH_OPT Default options structure for the IFRH.
%   IFRH_OPT returns the default options for the IFRH routine in a
%   structure with the following fields:
%
%      .n_fs_Hz - samples per second (int32) [32768]
%      .n_channels - number of input channels (int32) [256]
%      .n_bins - number of histogram bins (int32) [8001]
%      .n_ass_mode - assignment mode (int32)
%          0 = direct assignment [default]
%          1 = remapped
%      .n_ifr_wait - number of samples to wait before measuring
%                    instantaneous frequency (int32) [1]
%      .n_out_wait - number of samples to wait before outputting frame
%                    (int32) [1]
%      .d_freq_start - centre frequency of lowest bin in Hz (double) [0]
%      .d_freq_width - width of bin in Hz (double) [0.25]
%      .dp_taus_s - time constant of leak on histogram
%      .sp_maps - reassignment maps or empty if no reassign [default]
%                 a structure array with one element for each channel:
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (I)nstantaneous (FR)requency (H)istogram
%
% See also IFRH_MEAN.


% Construct and return default options structure
opt = struct( ...
    'n_fs_Hz', int32(32768), ...
    'n_channels', int32(256), ...
    'n_bins', int32(8001), ...
    'n_ass_mode', int32(0), ...
    'n_ifr_wait', int32(1), ...
    'n_out_wait', int32(1), ...
    'd_freq_start', 0, ...
    'd_freq_width', 0.25, ...
    'dp_taus_s', ones(8001, 1), ...
    'sp_maps', []);

% end of file %
