function varargout = ifrh_run(varargin)
% IFRH_RUN Run instantaneous frequency histogram (IFHR) algorithm.
%    IFRH_RUN(X, OPT) applies the IFHR to the signal X using the options
%    specified in OPT. The input is a real matrix with row count equal to
%    the number of channels specified in the .n_channels field of OPT and
%    the number of columns is equal to the number of input time samples.
%    The result is an MxN matrix where the number of rows, M, is equal to
%    the number of bins specified in the .n_bins field of OPT and the
%    number of columns, N, is equal to the colum count of X.
%
%    [Y, ST] = IFRH_RUN(X, OPT) returns the output in Y and the state of the
%    algorithm in ST.
% 
%    [Y, ST] = IFRH_RUN(X, OPT, ST) resumes the algorithm starting with
%    the state specified in ST. If ST is the empty matrix the default
%    initial state is used.
%
%    The algorithm requires that C and Mex code are compiled and linked.
% 
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (I)nstantaneous (FR)requency (H)istogram
%
% See also IFRH_OPT, MAKE_FIGURE6.


% Forward input and output to/from MEX
varargout = cell(nargout, 1);
[varargout{:}] = mx_ifrh_run(varargin{:});

% end of file %
