% MAKE_FIGURE4 Make Figure 4 for JASA paper.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (MAKE) materials for JASA paper.
%
% See also MAKE_FIGURE4_DATA1, MAKE_FIGURE4_DATA2.


% Load figure data
load(['data' filesep 'figure4_data1.mat']);
load(['data' filesep 'figure4_data2.mat']);

% Scale the figure
scale = 2;

% Position and create the figure
figpos = [1 1 scale*[3.3 3.3]];
figure(...
    'Units', 'inches', ...
    'Position', figpos, ...
    'Color', 'w', ...
    'InvertHardCopy', 'off', ...
    'PaperPositionMode', 'manual');

% Put axes on the figure (top-left)
axes(...,
    'Units', 'inches', ...
    'Position', scale*[0.5 2.0 1.1 1.2], ...
    'LineWidth', scale, ...
    'FontSize', 8*scale, ...
    'XLim', snrs_a([1 end]), ...
    'XTick', 0:10:60, ...
    'YLim', [0.4 1.1], ...
    'YTick', 0.5:0.1:1.0, ...
    'Layer', 'top');
hold on; box off

% Plot series
h1 = plot(snrs_a, snr_on_pc_a(:,1), 'k-', 'Color', [0.8 0.8 0.8]);
h2 = plot(snrs_a, snr_on_pc_a(:,2), 'k--');
h3 = plot(snrs_a, snr_on_pc_a(:,3), 'k:');
h4 = plot(snrs_a, snr_on_pc_a(:,4), 'k-');
h5 = plot(snrs_e, snr_on_pc_e(:,1), 'kx', 'MarkerSize', 6*scale);
h6 = plot(snrs_e, snr_on_pc_e(:,2), 'k.', 'MarkerSize', 10*scale);

% Set line widths
set(h1, 'LineWidth', 2*scale);
set([h2 h3 h4 h5 h6], 'LineWidth', scale);

% Plot parameter markers
plot([20 40], [0.4 0.4], 'k^', ...
    'MarkerSize', 3 * scale, ...
    'MarkerFaceColor', 'k', ...
    'LineWidth', scale);

% Add axis labels
xlabel 'SNR (dB)'
ylabel 'P(correct)'

% Put axes on the figure (top-right)
axes(...,
    'Units', 'inches', ...
    'Position', scale*[2.0 2.0 1.1 1.2], ...
    'LineWidth', scale, ...
    'FontSize', 8*scale, ...
    'XLim', snrs_a([1 end]), ...
    'XTick', 0:10:60, ...
    'YLim', [0.4 1.1], ...
    'YTick', 0.5:0.1:1.0, ...
    'Layer', 'top');
hold on; box off

% Plot series
h1 = plot(snrs_a, snr_off_pc_a(:,1), 'k-', 'Color', [0.8 0.8 0.8]);
h2 = plot(snrs_a, snr_off_pc_a(:,2), 'k--');
h3 = plot(snrs_a, snr_off_pc_a(:,3), 'k:');
h4 = plot(snrs_a, snr_off_pc_a(:,4), 'k-');
h5 = plot(snrs_e, snr_off_pc_e(:,1), 'kx', 'MarkerSize', 6*scale);
h6 = plot(snrs_e, snr_off_pc_e(:,2), 'k.', 'MarkerSize', 10*scale);

% Set line widths
set(h1, 'LineWidth', 2*scale);
set([h2 h3 h4 h5 h6], 'LineWidth', scale);

% Plot parameter markers
plot([20 40], [0.4 0.4], 'k^', ...
    'MarkerSize', 3 * scale, ...
    'MarkerFaceColor', 'k', ...
    'LineWidth', scale);

% Add axis labels
xlabel 'SNR (dB)'

% Put axes on the figure (bottom-left)
axes(...,
    'Units', 'inches', ...
    'Position', scale*[0.5 0.5 1.1 1.1], ...
    'LineWidth', scale, ...
    'FontSize', 8*scale, ...
    'XLim', [fqs_a([1 end])], ...
    'YLim', [0.4 1.1], ...
    'YTick', 0.5:0.1:1.0, ...
    'Layer', 'top');
hold on; box off

% Plot series
h1 = plot(fqs_a, fqs_lo_pc_a(:,1), 'k-', 'Color', [0.8 0.8 0.8]);
h2 = plot(fqs_a, fqs_lo_pc_a(:,2), 'k--');
h3 = plot(fqs_a, fqs_lo_pc_a(:,3), 'k:');
h4 = plot(fqs_a, fqs_lo_pc_a(:,4), 'k-');
h5 = plot(fqs_e, fqs_lo_pc_e(:,1), 'kx', 'MarkerSize', 6*scale);
h6 = plot(fqs_e, fqs_lo_pc_e(:,2), 'k.', 'MarkerSize', 10*scale);

% Set line widths
set(h1, 'LineWidth', 2*scale);
set([h2 h3 h4 h5 h6], 'LineWidth', scale);

% Plot parameter markers
plot([1000 1100], [0.4 0.4], 'k^', ...
    'MarkerSize', 3 * scale, ...
    'MarkerFaceColor', 'k', ...
    'LineWidth', scale);

% Add axis labels
xlabel 'Frequency (Hz)'
ylabel 'P(correct)'

% Put axes on the figure (bottom-right)
axes(...,
    'Units', 'inches', ...
    'Position', scale*[2.0 0.5 1.1 1.1], ...
    'LineWidth', scale, ...
    'FontSize', 8*scale, ...
    'XLim', [fqs_a([1 end])], ...
    'YLim', [0.4 1.1], ...
    'YTick', 0.5:0.1:1.0, ...
    'Layer', 'top');
hold on; box off

% Plot series
h1 = plot(fqs_a, fqs_hi_pc_a(:,1), 'k-', 'Color', [0.8 0.8 0.8]);
h2 = plot(fqs_a, fqs_hi_pc_a(:,2), 'k--');
h3 = plot(fqs_a, fqs_hi_pc_a(:,3), 'k:');
h4 = plot(fqs_a, fqs_hi_pc_a(:,4), 'k-');
h5 = plot(fqs_e, fqs_hi_pc_e(:,1), 'kx', 'MarkerSize', 6*scale);
h6 = plot(fqs_e, fqs_hi_pc_e(:,2), 'k.', 'MarkerSize', 10*scale);

% Set line widths
set(h1, 'LineWidth', 2*scale);
set([h2 h3 h4 h5 h6], 'LineWidth', scale);

% Plot parameter markers
plot([1000 1100], [0.4 0.4], 'k^', ...
    'MarkerSize', 3 * scale, ...
    'MarkerFaceColor', 'k', ...
    'LineWidth', scale);

% Add axis labels
xlabel 'Frequency (Hz)'

% Add annotation A
annotation( ...
    'textbox', ...
    'Units', 'inches', ...
    'Position', scale*[0 1.5+1.6 0.2 0.2], ...
    'String', 'A', ...
    'FontSize', 12*scale, ...
    'FontWeight', 'bold', ...
    'LineStyle', 'none');

% Add annotation B
annotation( ...
    'textbox', ...
    'Units', 'inches', ...
    'Position', scale*[0 1.5 0.2 0.2], ...
    'String', 'B', ...
    'FontSize', 12*scale, ...
    'FontWeight', 'bold', ...
    'LineStyle', 'none');

% end of file %
