% MAKE_FIGURE4_DATA1 Make Data Set 1 for Figure 4 for JASA paper.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (MAKE) materials for JASA paper.


% Set process options (minimum-error performance)
clear opt
opt.etas    = 1;
opt.ninterp = 0;

% Set base configuration
clear basecfg
basecfg.filter.cfHz   = 1000;
basecfg.filter.bwHz   = 160;
basecfg.signal.sinfHz = 1000;
basecfg.signal.bwHz   = 1;
basecfg.snr           = 20;
basecfg.fsHz          = 32768;

% Set SNRs and frequencies to test
snrs_a = 0:2:60;
fqs_a  = 800:4:1200;

% Reserve space for vary SNR/on-centre/percent correct/analytical
snr_on_pc_a = zeros(length(snrs_a), 4);

% Set configuration to signal at centre frequency of filter
cfg               = basecfg;
cfg.signal.sinfHz = 1000;

% Print message
fprintf('Four conditions to run. This may take a while.\n');
fprintf('[Con1] SNR on [of %d]: ', length(snrs_a));

% For each SNR n:
for n = 1:length(snrs_a)

    % Mark progress
    fprintf('.');

    % Set SNR
    cfg.snr = snrs_a(n);

    % Compute minimum error performance for
    % - envelope detector
    % - ZCI detector
    % - instantaneous frequency detector
    % - ZCI/pk detector
    env_res = env_sin_roc(cfg, opt);
    zci_res = zci_sin_roc(cfg, opt);
    ifr_res = ifr_sin_roc(cfg, opt);
    zpk_res = zci_sin_pk_roc(cfg, opt);
    
    % Store results
    snr_on_pc_a(n,1) = (env_res.pHit + 1 - env_res.pFA)/2;
    snr_on_pc_a(n,2) = (zci_res.pHit + 1 - zci_res.pFA)/2;
    snr_on_pc_a(n,3) = (ifr_res.pHit + 1 - ifr_res.pFA)/2;
    snr_on_pc_a(n,4) = (zpk_res.pHit + 1 - zpk_res.pFA)/2;
   
end

% Clear line
fprintf('\n');

% Reserve space for vary SNR/off-centre/percent correct/analytical
snr_off_pc_a = zeros(length(snrs_a), 4);

% Set configuration to signal off centre frequency of filter
cfg               = basecfg;
cfg.signal.sinfHz = 1100;

% Print message
fprintf('[Con2] SNR off [of %d]: ', length(snrs_a));

% For each SNR n:
for n = 1:length(snrs_a)

    % Mark progress
    fprintf('.');

    % Set SNR
    cfg.snr = snrs_a(n);

    % Compute minimum error performance for
    % - envelope detector
    % - ZCI detector
    % - instantaneous frequency detector
    % - ZCI/pk detector
    env_res = env_sin_roc(cfg, opt);
    zci_res = zci_sin_roc(cfg, opt);
    ifr_res = ifr_sin_roc(cfg, opt);
    zpk_res = zci_sin_pk_roc(cfg, opt);

    % Store results
    snr_off_pc_a(n,1) = (env_res.pHit + 1 - env_res.pFA)/2;
    snr_off_pc_a(n,2) = (zci_res.pHit + 1 - zci_res.pFA)/2;
    snr_off_pc_a(n,3) = (ifr_res.pHit + 1 - ifr_res.pFA)/2;
    snr_off_pc_a(n,4) = (zpk_res.pHit + 1 - zpk_res.pFA)/2;

end

% Clear line
fprintf('\n');

% Reserve space for vary frequency/low-SNR/percent correct/analytical
fqs_lo_pc_a = zeros(length(fqs_a), 4);

% Set configuration for low SNR
cfg     = basecfg;
cfg.snr = 20;

% Print message
fprintf('[Con3] Frequency [of %d]: ', length(fqs_a));

% For each SNR n:
for n = 1:length(fqs_a)

    % Mark progress
    fprintf('.');

    % Set signal frequency
    cfg.signal.sinfHz = fqs_a(n);

    % Compute minimum error performance for
    % - envelope detector
    % - ZCI detector
    % - instantaneous frequency detector
    % - ZCI/pk detector
    env_res = env_sin_roc(cfg, opt);
    zci_res = zci_sin_roc(cfg, opt);
    ifr_res = ifr_sin_roc(cfg, opt);
    zpk_res = zci_sin_pk_roc(cfg, opt);

    % Store results
    fqs_lo_pc_a(n,1) = (env_res.pHit + 1 - env_res.pFA)/2;
    fqs_lo_pc_a(n,2) = (zci_res.pHit + 1 - zci_res.pFA)/2;
    fqs_lo_pc_a(n,3) = (ifr_res.pHit + 1 - ifr_res.pFA)/2;
    fqs_lo_pc_a(n,4) = (zpk_res.pHit + 1 - zpk_res.pFA)/2;

end

% Clear line
fprintf('\n');

% Reserve space for vary frequency/high-SNR/percent correct/analytical
fqs_hi_pc_a = zeros(length(fqs_a), 4);

% Set configuration for high SNR
cfg     = basecfg;
cfg.snr = 40;

% Print message
fprintf('[Con4] Frequency [of %d]: ', length(fqs_a));

% For each frequency n:
for n = 1:length(fqs_a)

    % Mark progress
    fprintf('.');

    % Set signal frequency
    cfg.signal.sinfHz = fqs_a(n);

    % Compute minimum error performance for
    % - envelope detector
    % - ZCI detector
    % - instantaneous frequency detector
    % - ZCI/pk detector
    env_res = env_sin_roc(cfg, opt);
    zci_res = zci_sin_roc(cfg, opt);
    ifr_res = ifr_sin_roc(cfg, opt);
    zpk_res = zci_sin_pk_roc(cfg, opt);

    % Store results
    fqs_hi_pc_a(n,1) = (env_res.pHit + 1 - env_res.pFA)/2;
    fqs_hi_pc_a(n,2) = (zci_res.pHit + 1 - zci_res.pFA)/2;
    fqs_hi_pc_a(n,3) = (ifr_res.pHit + 1 - ifr_res.pFA)/2;
    fqs_hi_pc_a(n,4) = (zpk_res.pHit + 1 - zpk_res.pFA)/2;

end

% Clear line
fprintf('\n');

% Save data
save data\figure4_data1.mat snrs_a fqs_a ...
    snr_on_pc_a snr_off_pc_a fqs_hi_pc_a fqs_lo_pc_a

% end of file %
