% MAKE_FIGURE4_DATA2 Make Data Set 2 for Figure 4 for JASA paper.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (MAKE) materials for JASA paper.


% Set process options (minimum-error performance)
clear opt
opt.eta     = 1;
opt.ninterp = 0;

% Set base configuration
clear basecfg
basecfg.filter.cfHz   = 1000;
basecfg.filter.bwHz   = 160;
basecfg.signal.sinfHz = 1000;
basecfg.signal.bwHz   = 1;
basecfg.snr           = 20;
basecfg.fsHz          = 32768;

% Set SNRs and frequencies to test
snrs_e = 0:10:60;
fqs_e  = 800:100:1200;

% Reserve space for vary SNR/on-centre/percent correct/empirical
snr_on_pc_e = zeros(length(snrs_e), 2);

% Set configuration to signal at centre frequency of filter
cfg               = basecfg;
cfg.signal.sinfHz = 1000;

% Print message
fprintf('Four conditions to run. This may take a while.\n');
fprintf('[Con1] SNR on [of %d]: ', length(snrs_e));

% For each SNR n:
for n = 1:length(snrs_e)

    % Mark progress
    fprintf('.');

    % Set SNR
    cfg.snr = snrs_e(n);

    % Compute minimum error performance for ZCI/ZCI+pk detector
    zci_res = zci_sin_roc_emp(cfg, opt);
    zpk_res = zci_sin_pk_roc_emp(cfg, opt);

    % Store results
    snr_on_pc_e(n,1) = (zci_res.pHit + 1 - zci_res.pFA)/2;
    snr_on_pc_e(n,2) = (zpk_res.pHit + 1 - zpk_res.pFA)/2;

end

% Clear line
fprintf('\n');

% Reserve space for vary SNR/off-centre/percent correct/empirical
snr_off_pc_e = zeros(length(snrs_e), 2);

% Set configuration to signal off centre frequency of filter
cfg               = basecfg;
cfg.signal.sinfHz = 1100;

% Print message
fprintf('[Con2] SNR off [of %d]: ', length(snrs_e));

% For each SNR n:
for n = 1:length(snrs_e)

    % Mark progress
    fprintf('.');

    % Set SNR
    cfg.snr = snrs_e(n);

    % Compute minimum error performance for ZCI/ZCI+pk detector
    zci_res = zci_sin_roc_emp(cfg, opt);
    zpk_res = zci_sin_pk_roc_emp(cfg, opt);

    % Store results
    snr_off_pc_e(n,1) = (zci_res.pHit + 1 - zci_res.pFA)/2;
    snr_off_pc_e(n,2) = (zpk_res.pHit + 1 - zpk_res.pFA)/2;

end

% Clear line
fprintf('\n');

% Reserve space for vary frequency/low-SNR/percent correct/empirical
fqs_lo_pc_e = zeros(length(fqs_e), 2);

% Set configuration for low SNR
cfg     = basecfg;
cfg.snr = 20;

% Print message
fprintf('[Con3] Frequency [of %d]: ', length(fqs_e));

% For each frequency n:
for n = 1:length(fqs_e)

    % Mark progress
    fprintf('.');

    % Set signal frequency
    cfg.signal.sinfHz = fqs_e(n);

    % Compute minimum error performance for ZCI/ZCI+pk detector
    zci_res = zci_sin_roc_emp(cfg, opt);
    zpk_res = zci_sin_pk_roc_emp(cfg, opt);

    % Store results
    fqs_lo_pc_e(n,1) = (zci_res.pHit + 1 - zci_res.pFA)/2;
    fqs_lo_pc_e(n,2) = (zpk_res.pHit + 1 - zpk_res.pFA)/2;

end

% Clear line
fprintf('\n');

% Reserve space for vary frequency/high-SNR/percent correct/empirical
fqs_hi_pc_e = zeros(length(fqs_e), 2);

% Set configuration for high SNR
cfg     = basecfg;
cfg.snr = 40;

% Print message
fprintf('[Con4] Frequency [of %d]: ', length(fqs_e));

% For each frequency n:
for n = 1:length(fqs_e)

    % Mark progress
    fprintf('.');

    % Set signal frequency
    cfg.signal.sinfHz = fqs_e(n);

    % Compute minimum error performance for ZCI/ZCI+pk detector
    zci_res = zci_sin_roc_emp(cfg, opt);
    zpk_res = zci_sin_pk_roc_emp(cfg, opt);

    % Store results
    fqs_hi_pc_e(n,1) = (zci_res.pHit + 1 - zci_res.pFA)/2;
    fqs_hi_pc_e(n,2) = (zpk_res.pHit + 1 - zpk_res.pFA)/2;

end

% Clear line
fprintf('\n');

% Save data
save data\figure4_data2.mat snrs_e fqs_e ...
    snr_on_pc_e snr_off_pc_e fqs_hi_pc_e fqs_lo_pc_e

% end of file %
