% MAKE_FIGURE5 Make Figure 5 for JASA paper.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (MAKE) materials for JASA paper.
%
% See also MAKE_FIGURE5_DATA.


% Load figure data
load(['data' filesep 'figure5_data.mat']);

% Scale the figure
scale = 2;

% Position and create the figure
figpos = [1 1 scale*[3.3 3.3]];
figure(...
    'Units', 'inches', ...
    'Position', figpos, ...
    'Color', 'w', ...
    'InvertHardCopy', 'off', ...
    'PaperPositionMode', 'auto');

% Put axes on the figure
axes(...,
    'Units', 'inches', ...
    'Position', scale*[0.4 0.4 2.7 2.7], ...
    'LineWidth', scale, ...
    'FontSize', 8*scale, ...
    'XLim', [0 1], ...
    'XTick', 0:0.2:1, ...
    'YLim', [0 1], ...
    'YTick', 0:0.2:1, ...
    'Layer', 'top');
hold on; box on; grid on;

% Plot series (squared envelope detector)
plot(env_res1.pFA, env_res1.pHit, 'k-', ...
    'LineWidth', 2*scale, ...
    'Color', [0.8 0.8 0.8]);

% Plot series (zero crossing interval detector)
plot(zci_res1.pFA, zci_res1.pHit, 'k--', ...
    'LineWidth', scale);

% Plot series (zero crossing/peak amplitude detector)
plot(zpk_res1.pFA, zpk_res1.pHit, 'k-', ...
    'LineWidth', scale);

% Add annotation A
text(0.1, 0.9, 'A', 'FontSize', 8*scale, ...
    'HorizontalAlign', 'center', ...
    'VerticalAlign', 'middle');

% Plot series (squared envelope detector)
plot(env_res2.pFA, env_res2.pHit, 'k-', ...
    'LineWidth', 2*scale, ...
    'Color', [0.8 0.8 0.8]);

% Plot series (zero crossing interval detector)
plot(zci_res2.pFA, zci_res2.pHit, 'k--', ...
    'LineWidth', scale);

% Plot series (zero crossing/peak amplitude detector)
plot(zpk_res2.pFA, zpk_res2.pHit, 'k-', ...
    'LineWidth', scale);

% Add annotation B
text(0.45, 0.55, 'B', 'FontSize', 8*scale, ...
    'HorizontalAlign', 'center', ...
    'VerticalAlign', 'middle');

% Chance performance
plot([0 1], [0 1], 'k:', 'LineWidth', scale);

% Add axis labels
title 'Receiver Operating Characteristics'
xlabel 'P(FA)'
ylabel 'P(Hit)'

% end of file %
