% MAKE_FIGURE5_DATA Make Data Set for Figure 5 for JASA paper.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (MAKE) materials for JASA paper.


% Set process options (minimum-error performance)
clear opt
opt.etas    = logspace(-2.5, 2.5, 10);
opt.ninterp = 20;

% Set base configuration
clear basecfg
basecfg.filter.cfHz   = 1000;
basecfg.filter.bwHz   = 160;
basecfg.signal.sinfHz = 1000;
basecfg.signal.bwHz   = 1;
basecfg.snr           = 30;
basecfg.fsHz          = 32768;

% Use base configuration
cfg = basecfg;

% Start timer
tic;

% Set SNR to 30 dB and signal frequency to 1000 Hz (centre)
disp('Producing ROC curve SNR=30 freq=1000...');
cfg.signal.sinfHz = 1050;

% Compute performance of envelope, interval and peak+interval detector
env_res1 = env_sin_roc(cfg, opt);
zci_res1 = zci_sin_roc(cfg, opt);
zpk_res1 = zci_sin_pk_roc(cfg, opt);

% Set SNR to 30 dB and signal frequency to 1100 Hz (off-centre)
disp('Producing ROC curve SNR=30 freq=1100...');
cfg.signal.sinfHz = 1100;

% Compute performance of envelope, interval and peak+interval detector
env_res2 = env_sin_roc(cfg, opt);
zci_res2 = zci_sin_roc(cfg, opt);
zpk_res2 = zci_sin_pk_roc(cfg, opt);

% Stop timer
toc;

% Save data
save(['data' filesep 'figure5_data.mat'], ...
    'env_res1','zci_res1','zpk_res1', ...
    'env_res2','zci_res2','zpk_res2', ...
    'basecfg');

% end of file %
