% MAKE_FIGURE7 Make Figure 7 for JASA paper.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (MAKE) materials for JASA paper.
%
% See also MAKE_FIGURE7AND8_DATA.


% Set scale and contrast values
scale    = 1;
contrast = 0.8;

% Set y-edges for positioning elements on figure
yedge1 = 0.0;
yedge2 = 1.2;
yedge3 = 4.0;

cfix = [16 26 28];

% Load data for figure production
disp('Loading data...');
load(['data' filesep 'figure7and8_data.mat']);

% Get sample rate in Hertz
fsHz = double(swopt.n_fs_Hz);

% Create a figure
figpos = [1 1 scale*[3.3 5.5]];
figure(...
    'Units', 'inches', ...
    'Position', figpos, ...
    'Color', 'w', ...h
    'InvertHardCopy', 'off', ...
    'PaperPositionMode', 'manual');

% Place axes on figure
axespos = scale*[0.5 yedge3+0.6 2.6 0.5];
axes(...
    'Units', 'inches', ...
    'Position', axespos, ...
    'LineWidth', scale, ...
    'FontSize', 8*scale, ...
    'Layer', 'top', ...
    'XLim', [1300 2000], ...
    'XTickLabel', []);
hold on; box off;

% Plot noise power spectral density
icfHz = linspace(cfHz(1), cfHz(end), 1000);
plot(icfHz, mgm_eval(MSs, 2*pi*icfHz, 'real'), ...
    'k', ...
    'LineWidth', scale);

% Add axis title
title 'Noise Power Spectral Density'

% Place axes on figure
axespos = scale*[0.5 yedge3 2.6 0.2];
axes(...
    'Units', 'inches', ...
    'Position', axespos, ...
    'LineWidth', scale, ...
    'FontSize', 8*scale, ...
    'Layer', 'top', ...
    'XLim', [1300 2000], ...
    'YLim', [0 1.1], ...
    'XTickLabel', [], ...
    'YTickLabel', []);
hold on; box off;

% For each filter output n:
for n = 1:length(Mfb)
    
    if ismember(n, cfix), color = 'k'; else color = [0.8 0.8 0.8]; end
    
    % Get magnitude response of filter and plot it
    MHs   = mgm_abs2(mgm_fourier(Mfb{n}));
    Hs    = mgm_eval(MHs, 2*pi*fqHz, 'real');
    plot(fqHz, Hs/max(Hs), 'k', ...
        'LineWidth', scale, ...
        'Color', color);
    
end

set(gca, 'XTick', cfHz(cfix), 'XTickLabel', {'(i)', '(ii)', '(iii)'});

% Add title
title('Analysis Bands')

% Place axes on figure
axespos = scale*[0.5 yedge2+1.45 2.6 0.8];
axes(...
    'Units', 'inches', ...
    'Position', axespos, ...
    'LineWidth', scale, ...
    'FontSize', 8*scale, ...
    'Layer', 'top', ...
    'XLim', [1300 2000], ...
    'YLim', [-0.5 10], ...
    'XTickLabel', [], ...
    'CLim', [0.1 max(ZCIH(:))]);
hold on; box on;

h = imagesc(fqHz, tsec, ZCIH');
colormap((1 - gray).^contrast);
plot(ifrHz, tsec, 'w', 'LineWidth', 0.5*scale);

ylabel 'Time (s)'
title 'ZCIH'

% Place axes on figure
axespos = scale*[0.5 yedge2+0.4 2.6 0.8];
axes(...
    'Units', 'inches', ...
    'Position', axespos, ...
    'LineWidth', scale, ...
    'FontSize', 8*scale, ...
    'Layer', 'top', ...
    'XLim', [1300 2000], ...
    'YLim', [-0.5 10], ...
    'CLim', [0.1 max(ZCIH(:))]);
hold on; box on;

imagesc(fqHz, tsec, RZCIH');
colormap((1 - gray).^contrast);
plot(ifrHz, tsec, 'w', 'LineWidth', 0.5*scale);

xlabel 'Frequency (Hz)'
ylabel 'Time (s)'
title 'DR-ZCIH'

% Place axes on figure
axespos = scale*[0.5 yedge1+0.4 1.1 0.6];
axes(...
    'Units', 'inches', ...
    'Position', axespos, ...
    'LineWidth', scale, ...
    'FontSize', 8*scale, ...
    'Layer', 'top', ...
    'XLim', [1400 1600], ...
    'YLim', [0.05 0.3], ...
    'YTick', 0:0.1:0.3, ...
    'CLim', [0 max(ZCIH(:))]);
hold on; box off;

% Select cells to produce mean plots from
tcells = tsec(1:1024:end) + double(swopt.n_dft_len)/fsHz;
ix     = tcells > 0 & tcells < 3;

% Plot means of ZCIH and rZCIHs
plot(fqHz, mean(ZCIH(:,ix), 2)/max(mean(ZCIH(:,ix), 2)).^0, 'k', ...
    'LineWidth', 1.5*scale, ...
    'Color', [0.8 0.8 0.8]);
plot(fqHz, mean(RZCIH(:,ix), 2)/max(mean(RZCIH(:,ix), 2)).^0, 'k', ...
    'LineWidth', scale);
plot([1500 1500], [0 0.6], 'k:', 'LineWidth', scale);

% Place axes on figure
axespos = scale*[1.95 yedge1+0.4 1.1 0.6];
axes(...
    'Units', 'inches', ...
    'Position', axespos, ...
    'LineWidth', scale, ...
    'FontSize', 8*scale, ...
    'Layer', 'top', ...
    'XLim', [1700 1900], ...
    'YLim', [0.05 0.3], ...
    'YTick', 0:0.1:0.3, ...
    'CLim', [0 max(ZCIH(:))]);
hold on; box off;

% Select cells to produce mean plots from
ix = tcells > 7 & tcells < 10;

% Plot means of ZCIH and rZCIHs
plot(fqHz, mean(ZCIH(:,ix), 2)/max(mean(ZCIH(:,ix), 2)).^0, 'k', ...
    'LineWidth', 1.5*scale, ...
    'Color', [0.8 0.8 0.8]);
plot(fqHz, mean(RZCIH(:,ix), 2)/max(mean(RZCIH(:,ix), 2)).^0, 'k', ...
    'LineWidth', scale);
plot(ifrHz(end)*[1 1], [0 1], 'k:', 'LineWidth', scale);

% Annotate panel A
annotation('textbox', ...
    'Units', 'inches', ...
    'Position', scale*[0.1 yedge3+1.2 0.2 0.2], ...
    'String', 'A', ...
    'FontSize', 12, ...
    'FontWeight', 'bold', ...
    'LineStyle', 'none');

% Annotate panel B
annotation('textbox', ...
    'Units', 'inches', ...
    'Position', scale*[0.1 yedge2+2.4 0.2 0.2], ...
    'String', 'B', ...
    'FontSize', 12, ...
    'FontWeight', 'bold', ...
    'LineStyle', 'none');

% Annotate panel C
annotation('textbox', ...
    'Units', 'inches', ...
    'Position', scale*[0.1 yedge1+1.1 0.2 0.2], ...
    'String', 'C', ...
    'FontSize', 12*scale, ...
    'FontWeight', 'bold', ...
    'LineStyle', 'none');

% end of file %
