function make_figure8
% MAKE_FIGURE8 Make Figure 8 for JASA paper.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (MAKE) materials for JASA paper.
%
% See also MAKE_FIGURE7AND8_DATA.


% Set scale and contrast values
scale = 1;

% Load data for figure production
disp('Loading data...');
load(['data' filesep 'figure7and8_data.mat'],'swopt','rzcopt','fqHz','cfHz');

% Get sample rate in Hertz
fsHz = double(swopt.n_fs_Hz);

% Create a figure
figpos = [1 1 scale*[3.3 7.1]];
figure(...
    'Units', 'inches', ...
    'Position', figpos, ...
    'Color', 'w', ...h
    'InvertHardCopy', 'off', ...
    'PaperPositionMode', 'manual');
        
make_subfig(16, 2.25*2, '(i)', false);
make_subfig(26, 2.25*1, '(ii)', false);
make_subfig(28, 0, '(iii)', true);

    function make_subfig(cfix, yedge, letter, dolabel)
        
        % Place axes on figure
        axespos = scale*[0.9 0.5+yedge 2.0 2.0];
        axes(...
            'Units', 'inches', ...
            'Position', axespos, ...
            'LineWidth', scale, ...
            'FontSize', 8*scale, ...
            'Layer', 'top', ...
            'XTickLabel', []);
        
      	is = double(0:rzcopt.sp_maps(cfix).n_zci_count - 1);
        is = is * rzcopt.sp_maps(cfix).d_zci_width;
        is = is + rzcopt.sp_maps(cfix).d_zci_start;
        
        fqix = 1:rzcopt.sp_maps(cfix).n_bin_count;
        fqix = fqix + rzcopt.sp_maps(cfix).n_bin_start;
        
        % Get sample rate in Hertz
        fsHz = double(swopt.n_fs_Hz);
        
        h = imagesc(fliplr(0.5./is), ...
            fqHz(fqix), ...
            fliplr(rzcopt.sp_maps(cfix).dp_pdf));
        colormap(1-gray.^2);
        %set(h, 'LineStyle', 'none');
        
        hold on
        plot(0.5./is, 1./is/2, 'w', 'LineWidth', scale);
        plot(0.5./is, rzcopt.sp_maps(cfix).dp_pdf' * fqHz(fqix)', 'w-', ...
            'LineWidth', scale)
        
        plot([0 10000], cfHz(cfix)*[1 1], 'k', 'LineWidth', scale);
        plot([0 10000], cfHz(cfix)*[1 1], 'w:', 'LineWidth', scale);
        
        plot(cfHz(cfix)*[1 1], [0 10000], 'k', 'LineWidth', scale);
        plot(cfHz(cfix)*[1 1], [0 10000], 'w:', 'LineWidth', scale);
        
        axis xy
        
        if dolabel
            xlabel 'Naive Frequency (Hz)';
        end
        
        ylabel 'Remapped Frequency (Hz)'
   
        annotation('textbox', ...
            'Units', 'inches', ...
            'Position', scale*[0.1 yedge+2.3 0.25 0.25], ...
            'String', letter, ...
            'FontSize', 10*scale, ...
            'LineStyle', 'none');
        
    end

end

% end of file %
