function Mz = mgm_abs2(Mx)
% MGM_ABS2 Squared-magnitude of a modulated Gaussian mixture.
%    MGM_ABS2(MX) returns the squared magnitude of the Gaussian mixture MX.
%    It performs this computation by squaring the real and imaginary parts
%    separately and then performing an addition.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (M)odulated (G)aussian (M)ixtures
%
% See also MGM_REAL, MGM_IMAG.


% Compute the real part and square
Mre = mgm_real(Mx);
Mre = mgm_multiply(Mre, Mre);

% Compute the imaginary part and square
Mim = mgm_imag(Mx);
Mim = mgm_multiply(Mim, Mim);

% Sum the squared components
Mz = mgm_add(Mre, Mim);

% end of file %
