function sig = mgm_bw2sig(bwHz, dB, domain)
% MGM_BW2SIG Compute sigma parameter corresponding to a Hz bandwidth.
%    MGM_BW2SIG(BWHZ) returns a Gaussian component with a 3 dB bandwidth of
%    BWHZ Hertz. Note that the underlying scale in the Fourier domain for
%    MGMs is radians per second.
%
%    MGM_BW2SIG(BWHZ, DB) returns a Gaussian component whose bandwidth
%    measured between the points DB decibels down from the peak is BWHZ.
%
%    MGM_BW2SIG(BWHZ, DB, 'time') returns a single complex component in the
%    time domain, whose Fourier transform has a bandwidth of BWHZ Hertz
%    DB decibels down from the peak.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (M)odulated (G)aussian (M)ixtures
%
% See also MGM_FOURIER, MGM_IFOURIER, MGM_CONV.


% Use defaults?
if nargin < 2 || isempty(dB), dB = 3; end
if nargin < 3, domain = []; end

% Compute sigma
a   = 10^(-dB./10);
sig = (pi*bwHz)/sqrt(-2*log(a));

% Return sigma in the time domain
if strcmpi(domain, 'time'), sig = 1./sig; end

% end of file %
