function Mgas = mgm_fbank_autocov(Mfb, MSs)
% MGM_FBANK_AUTOCOV Compute autocovariance of filter outputs.
%    MGM_FBANK_AUTOCOV(MFB, MSs) returns the autocovariance at the output
%    of the filter bank MFB in response to an input process with power
%    spectral density MSS. MFB is a cell array of impulse responses (e.g.,
%    created using MGM_FBANK_CREATE).
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (M)odulated (G)aussian (M)ixtures
%
% See also MGM_FBANK_CREATE.


% Compute magnitude of frequency response for each filter
MSfb = cellfun(@mgm_fourier, Mfb, 'UniformOutput', false);
MSfb = cellfun(@mgm_abs2, MSfb, 'UniformOutput', false);

% Multiply each filter magnitude response by p.s.d. of input
fn_mult = @(M) mgm_multiply(M, MSs);

% Compute power spectral densities at output
MSout = cellfun(fn_mult, MSfb, 'UniformOutput', false);

% Compute autocovariances using W-K relations
Mgas = cellfun(@mgm_ifourier, MSout, 'UniformOutput', false);
Mgas = cellfun(@mgm_simplify, Mgas, 'UniformOutput', false);

% end of file %
