function Mz = mgm_fourier(Mx)
% MGM_FOURIER Compute Fourier transform of an MGM.
%    MGM_FOURIER(MX) returns non-unitary the Fourier transform of MX as
%    another modulated Gaussian mixture whose evaluation parameter is an
%    angular frequency. This operation is carried out component-wise, so
%    the result has the same dimensions as the input.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (M)odulated (G)aussian (M)ixtures
%
% See also MGM_IFOURIER, MGM_CONV.


% Reserve space for an MGM of the same size
Mz = mgm_create(size(Mx));

% For each component n in Mx:
for n = 1:numel(Mx)

    % Get component
    mx = Mx(n);

    % Compute component fields
    Mz(n).A   = mx.A*sqrt(2*pi)*mx.sig;
    Mz(n).sig = 1 / mx.sig;
    Mz(n).mu  = mx.w;
    Mz(n).w   = -mx.mu;
    Mz(n).phi = mx.phi + mx.mu*mx.w;

end

% end of file %
