function Mz = mgm_hilbert(Mx, option)
% MGM_HILBERT Compute Hilbert transform of an MGM.
%    MGM_HILBERT(MX) returns the Hilbert transform of the narrowband MGM
%    MX. Note that it is important that MX is in fact narrowband.
%
%    MGM_HILBERT(MX, 'full') returns the result in the matrix form
%    [MX iH{MX}], where MX is the original input and iH{MX} is the Hilbert
%    transform of MX multiplied by an imaginary unit.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (M)odulated (G)aussian (M)ixtures
%
% See also MGM_COS, MGM_SIN.


% Use defaults?
if nargin < 2 || isempty(option), option = ''; end

% Copy the components into another mixture
Mz = Mx;

% For each component n in Mx:
for n = 1:numel(Mx)

    % Get component
    m = Mx(n);

    % Shift the phase of the component
    if m.w > 0, Mz(n).phi = mod(m.phi + 3/2*pi, 2*pi); end
    if m.w < 0, Mz(n).phi = mod(m.phi + 1/2*pi, 2*pi); end

end

% Return full matrix of components
if strcmpi(option, 'full')

    % Return real and imaginary components in separate columns
    Mz = [Mx mgm_scale(Mz, 1i)];

end

% end of file %
