function Mz = mgm_ifourier(Mx)
% MGM_IFOURIER Compute inverse Fourier transform of an MGM.
%    MGM_FOURIER(MX) returns the inverse Fourier transform of MX as
%    another modulated Gaussian mixture whose evaluation parameter is time.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (M)odulated (G)aussian (M)ixtures
%
% See also MGM_FOURIER, MGM_CONV.


% Reserve space for an MGM of the same size
Mz = mgm_create(size(Mx));

% For each component n in Mx:
for n = 1:numel(Mz)

    % Get component
    mx = Mx(n);

    % Compute component fields
    Mz(n).A   = mx.A*mx.sig/sqrt(2*pi);
    Mz(n).sig = 1 / mx.sig;
    Mz(n).mu  = -mx.w;
    Mz(n).w   = mx.mu;
    Mz(n).phi = mx.phi + mx.mu*mx.w;

end

% end of file %
