function y = mgm_integrate(Mx, option)
% MGM_INTEGRATE Integrate a modulated Gaussian mixture on infinite bounds.
%    MGM_INTEGRATE(MX) evaluates the integral of MX on the bounds
%    (-infinity, infinity). To recall how the mixture is evaluated, see
%    MGM_EVAL. In general, complex values are returned.
% 
%    MGM_INTEGRATE(MX, 'real') returns the real value only. This flag
%    should be used if the result ought to be real, because small imaginary
%    values may otherwise accumulate due to rounding errors.
%
%    MGM_INTEGRATE(MX, 'imag') returns the imaginary value only.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (M)odulated (G)aussian (M)ixtures
%
% See also MGM_EVAL.


% Set accumulator to zero
y = 0;

% For each component n in Mx:
for n = 1:numel(Mx)

    % Get component and perform integration
    m = Mx(n);
    y = y + m.A * sqrt(2*pi*m.sig^2) * ...
        exp(1i*(m.phi + m.w*m.mu) - m.sig^2*m.w^2/2);

end

% Enforce real or imaginary output?
if nargin > 1 && strcmpi(option, 'real'), y = real(y); end
if nargin > 1 && strcmpi(option, 'imag'), y = imag(y); end

% end of file %
