function Mz = mgm_norm(Mx, option)
% MGM_NORM Normalise an MGM.
%    MGM_NORM(MX, 'rms') returns a version of MX, normalised so that its
%    mean square and r.m.s. are one.
%
%    MGM_NORM(MX, 'area') returns a version of MX, normalised so that its
%    area is one.
%
%    MGM_NORM(MX, 'zero') returns a version of MX, normalised so that its
%    value at zero is one.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (M)odulated (G)aussian (M)ixtures
%
% See also MGM_SCALE.


% Depending on the option:
switch lower(option)

    case 'rms'

        % Normalise to unit r.m.s.
        Mz = mgm_scale(Mx, 1./sqrt(mgm_integrate(mgm_abs2(Mx))));

    case 'area'

        % Normalise area underneath the MGM
        Mz = mgm_scale(Mx, real(1./mgm_integrate(Mx)));

    case 'zero'

        % Normalise MGM so that the value at zero is unity
        Mz = mgm_scale(Mx, 1./mgm_eval(Mx, 0, 'real'));

    otherwise

        % Error message
        error('Unknown option passed to MGM_NORM.');

end

% end of file %
