function Mz = mgm_scale(Mx, scale)
% MGM_SCALE Scale modulated Gaussian mixtures by a constant factor.
%    MGM_SCALE(MX, SCALE) returns a version of the MX scaled by a factor
%    SCALE. The angular and magnitude parts are applied separately.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (M)odulated (G)aussian (M)ixtures
%
% See also MGM_NEGATE, MGM_NORM.


% Copy the mixture
Mz = Mx;

% For each component n in Mx:
for n = 1:numel(Mx)

    % Get component
    mx = Mx(n);

    % Rescale and shift
    Mz(n).A   = abs(scale) * mx.A;
    Mz(n).phi = mod(Mx(n).phi + angle(scale), 2*pi);

end

% end of file %
