function Mhs = swdft_mgm(swopt)
% SWDFT_MGM Build an MGM filterbank.
%    SWDFT_MGM(SWOPT) builds a filter bank of model impulse responses given
%    the parameters in SWOPT (see SWDFT_OPT). The filter bank impulse
%    responses are constructed using MGM_FBANK_CREATE. The result is a
%    cell array.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (S)liding (W)indow (D)iscrete (F)ourier (T)ransform
%
% See also SWDFT, SWDFT_WINDOW, SWDFT_OPT.


% Get sample rate and DFT length
fsHz = double(swopt.n_fs_Hz);
ndft = double(swopt.n_dft_len);

% Get (zero-based index of) first cell and number of cells
cell1 = swopt.n_cell_start;
celln = swopt.n_cell_count;

% Compute centre frequencies and bandwidths...
cfHz = double((0:celln-1) + cell1) * fsHz/ndft;
bwHz = swopt.d_bw_Hz;

% ...use these to construct analytical impulse responses
Mhs = mgm_fbank_create(cfHz, bwHz, ndft/fsHz/2);

% end of file %
