function opt = swdft_opt
% SWDFT_OPT Sliding window DFT options.
%   SWDFT_OPT returns the default options for the sliding window discrete
%   Fourier transform routine in a structure with the following fields:
%
%      .n_fs_Hz - samples per second (int32) [16384]
%      .n_dft_len - length of DFT (int32) [16384]
%      .n_cell_start - zero-based index of first cell (int32) [0]
%      .n_cell_count - number of cells (int32) [256]
%      .n_fringe - number of cells of fringe (int32) [0]
%      .d_bw_Hz - bandwidth of filters in Hz (double) [1]
%      .d_leak - leak on filter (double) [1.0]
%      .dc_f_win - frequency domain window (double, must be complex)
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (S)liding (W)indow (D)iscrete (F)ourier (T)ransform
%
% See also SWDFT_RUN, SWDFT_WINDOW, SWDFT_FRINGE.


% Construct and return default options structure
opt = struct( ...
    'n_fs_Hz', int32(16384), ...
    'n_dft_len', int32(16384), ...
    'n_cell_start', int32(0), ...
    'n_cell_count', int32(256), ...
    'n_fringe', int32(0), ...
    'd_bw_Hz', 1, ...
    'd_leak', double(1), ...
    'dc_f_win', complex(1));

% end of file %
