function varargout = swdft_run(varargin)
% SWDFT_RUN Run sliding window discrete Fourier transform.
%    SWDFT_RUN(X, OPT) applies the sliding window DFT to the signal X using
%    the options specified in OPT. The result is an MxN matrix where the
%    number of rows, M, is equal to the number of channels specified in the
%    .n_cell_count field of OPT and the number of columns, N, is equal to
%    the length of X. The input is real and the output is complex.
%
%    [Y, ST] = SWDFT_RUN(X, OPT) returns the output in Y and the state of the
%    algorithm in ST.
% 
%    [Y, ST] = SWDFT_RUN(X, OPT, ST) resumes the algorithm starting with
%    the state specified in ST. If ST is the empty matrix the default
%    initial state is used.
%
%    The algorithm requires that C and Mex code are compiled and linked.
% 
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (S)liding (W)indow (D)iscrete (F)ourier (T)ransform
%
% See also SWDFT_OPT, MAKE_FIGURE6.


% Forward input and output to/from MEX
varargout = cell(nargout, 1);
[varargout{:}] = mx_swdft_run(varargin{:});

% end of file %
