function hs = util_contours(xs, ys, S, vals, winw)
% UTIL_CONTOURS Add up modulated Gaussian mixtures.
%    UTIL_CONTOURS(XS, YS, S, VALS) takes a surface in matrix X with
%    edge coordinates XS and YS and plots contours at the values (levels)
%    VALS.
%
%    UTIL_CONTOURS(XS, YS, S, VALS, WINW) performs the contour plot but
%    smooths the surface with a window of width WINW before plotting.
%
%    HS = UTIL_CONTOURS(...) returns handles to the contour lines in HS.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (UTIL)ity functions for the JASA paper


% Use defaults?
if nargin < 5 || isempty(winw), winw = 1; end

% Make a window to pre-smooth the surface
win = bsxfun(@times, gausswin(winw), gausswin(winw)');
win = win/sum(win(:));

% Convolve the surface with the window
Ss = convn(S, win, 'same');

% Compute contours
C = contourc(xs, ys, Ss, vals);

% Empty vector to accumulate handles into
hs = [];

% While there is contour data left to process:
while ~isempty(C)

    % Get contour data and plot contour
    n  = C(2,1);
    hs = [hs; line(C(1,2:n+1), C(2,2:n+1), zeros(n,1))]; %#ok

    % Strip contour from front of coordinate matrix
    C(:,1:n+1) = [];

end

% end of file %
