function H = util_hist3(data, xctrs, yctrs)
% UTIL_HIST3 Histogram data along two dimensions.
%    UTIL_HIST3(DATA, XCTRS, YCTRS) compiles the values in DATA into a
%    histogram with centres XCTRS in the first dimension and YCTRS in the
%    second dimension. DATA is a matrix with two columns and rows for each
%    data point.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (UTIL)ity functions for the JASA paper


% Make sure centre vectors are columns
xctrs = xctrs(:);
yctrs = yctrs(:);

% Compute edges between centres
xe = [diff(xctrs)/2 + xctrs(1:end-1); Inf];
ye = [diff(yctrs)/2 + yctrs(1:end-1); Inf];

% Create space for histogram
H = zeros(numel(xctrs), numel(yctrs));

% For each data element n:
for n = 1:size(data, 1)

    % Find bin into which data belongs
    ix = find(xe > data(n,1), 1, 'first');
    iy = find(ye > data(n,2), 1, 'first');

    % Add to bin
    H(ix,iy) = H(ix,iy) + 1;

end

% end of file %
