function pdf = util_ncx2_2df(u, sinA)
% UTIL_NCX2_2DF Non-central chi-squared density function with 2 degrees freedom.
%    UTIL_NCX2_2DF(U, SINA) evaluates the p.d.f. of the chi-square
%    distribution's density function at points U when the distribution has
%    non-centrality parameter SINA^2 and two degrees of freedom.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (UTIL)ity functions for the JASA paper


% Reserve space for pdf
pdf = zeros(size(u));

% Precompute argument 
qs = sqrt(u) * sinA;

% Compute pdf
ix = qs < 50;
pdf(ix) = exp(-(u(ix) + sinA^2)/2) / 2;
pdf(ix) = pdf(ix) .* besseli(0, qs(ix));

% Compute pdf
% large argument approximation for Bessel function
iy = ~ix;
pdf(iy) = exp(-(sqrt(u(iy)) - sinA).^2/2) / 2;
pdf(iy) = pdf(iy) ./ sqrt(2*pi * qs(iy));

% end of file %
