function icdf = zci_cdf(Mrho, is)
% ZCI_CDF Zero crossing interval cumulative distribution function.
%    ZCI_CDF(MRHO, IS) returns the c.d.f. of the zero crossing intervals
%    for a Gaussian random process with autocorrelation MRHO, where MRHO is
%    an additive mixture of modulated Gaussians. The intervals are given in
%    IS, in seconds.
% 
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (Z)ero (C)rossing (I)ntervals
%
% See also ZCI_PDF, ZCI_SIN_HIST.


% Evaluate autocorrelation coefficient and derivatives.
rho     = mgm_eval(Mrho, is, 'real');
rhod    = mgm_evald(Mrho, is, 'real');
rhod2_0 = mgm_evald2(Mrho, 0, 'real');

% Evaluate c.d.f.
icdf = real(1/2 + rhod./sqrt(rhod2_0*(rho.^2 - 1))/2);

% end of file %
