function ipdf = zci_pdf(Mrho, is)
% ZCI_PDF Zero crossing interval probability density function.
%    ZCI_PDF(MRHO, IS) returns the p.d.f. of the zero crossing intervals
%    for a Gaussian random process with autocorrelation MRHO, where MRHO is
%    an additive mixture of modulated Gaussians. The intervals are given in
%    IS, in seconds.
% 
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (Z)ero (C)rossing (I)ntervals
%
% See also ZCI_CDF, ZCI_SIN_HIST.


% Evaluate autocorrelation coefficient and derivatives.
rho   = mgm_eval(Mrho, is, 'real');
rhod  = mgm_evald(Mrho, is, 'real');
rhod2 = mgm_evald2(Mrho, is, 'real');

% Compute numerator and denominator of interval p.d.f.
A      = rho.^2 - 1;
ipdf_n = rho .* rhod.^2 - A .* rhod2;
ipdf_d = 2 * sqrt(mgm_evald2(Mrho, 0) * A.^3);

% Compute interval p.d.f.
ipdf = real(ipdf_n ./ ipdf_d);

% end of file %
