function varargout = zcpa_run(varargin)
% ZCPA_RUN Run zero crossings/peak amplitudes (ZCPA) algorithm.
%    ZCPA_RUN(X, OPT) applies the ZCPA to the signal X using the options
%    specified in OPT. The input is a real matrix with row count equal to
%    the number of channels specified in the .n_channels field of OPT and
%    the number of columns is equal to the number of input time samples.
%    The result is an MxN matrix where the number of rows, M, is equal to
%    the number of bins specified in the .n_bins field of OPT and the
%    number of columns, N, is equal to the colum count of X.
%
%    [Y, ST] = ZCPA_RUN(X, OPT) returns the output in Y and the state of the
%    algorithm in ST.
% 
%    [Y, ST] = ZCPA_RUN(X, OPT, ST) resumes the algorithm starting with
%    the state specified in ST. If ST is the empty matrix the default
%    initial state is used.
%
%    The algorithm requires that C and Mex code are compiled and linked.
% 
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield
% Part of: (Z)ero (C)rossings with (P)eak (A)mplitudes
%
% See also ZCPA_OPT, MAKE_FIGURE6.


% Forward input and output to/from MEX
varargout = cell(nargout, 1);
[varargout{:}] = mx_zcpa_run(varargin{:});

% end of file %
