% BUILDC Compile and link all MEX code.
%
% Author: Robert Mill <rob.mill.uk@gmail.com>
% (C)2015 University of Sheffield


% Preserve current working directory
storedpath = pwd;

% Change to the directory where this code is located
cd(fileparts(mfilename('fullpath')))

% Try to compile:
try

    % Clean binaries
    disp('Cleaning bin directory...');
    delete bin/*.obj
    delete bin/*.o
    delete bin/*.lib
    delete bin/*.mexw32

    % Compile import routines
    disp('Compiling mx_read.c [Matlab > C interface routines] ...');
    mex -c -outdir bin -Isrc -I../C/src src/mx_read.c

    % Compile export routines
    disp('Compiling mx_write.c [C > Matlab interface routines] ...');
    mex -c -outdir bin -Isrc -I../C/src src/mx_write.c

    % Compile interface for sliding window DFT
    disp('Compiling mx_swdft.c [Sliding Window DFT MEX interface] ...');
    mex -c -outdir bin -Isrc -I../C/src src/mx_swdft.c

    % Compile interface for zero crossing with peak amplitudes
    disp('Compiling mx_zcpa.c [ZCPA MEX interface] ...');
    mex -c -outdir bin -Isrc -I../C/src src/mx_zcpa.c

    % Compile interface for instantaneous frequency histogram
    disp('Compiling mx_ifrh.c [Instantaneous Frequency Histogram] ...');
    mex -c -outdir bin -Isrc -I../C/src src/mx_ifrh.c

    % Running on UNIX?
    if isunix

        % Link SWDFT on UNIX
        disp('Linking mx_swdft_run.c ...');
        mex -outdir bin -Isrc -I../C/src src/mx_swdft_run.c ...
            bin/mx_read.o bin/mx_write.o bin/mx_swdft.o ...
            ../C/bin/swdft.o

        % Link ZCPA on UNIX
        disp('Linking mx_zcpa_run.c ...');
        mex -outdir bin -Isrc -I../C/src src/mx_zcpa_run.c ...
            bin/mx_read.o bin/mx_write.o bin/mx_zcpa.o ...
            ../C/bin/zcpa.o

        % Link IFRH on UNIX
        disp('Linking mx_ifrh_run.c ...');
        mex -outdir bin -Isrc -I../C/src src/mx_ifrh_run.c ...
            bin/mx_read.o bin/mx_write.o bin/mx_ifrh.o ...
            ../C/bin/ifrh.o

    else

        % Link SWDFT on Windows
        disp('Linking mx_swdft_run.c ...');
        mex -outdir bin -Isrc -I../C/src src/mx_swdft_run.c ...
            bin/mx_read.obj bin/mx_write.obj bin/mx_swdft.obj ...
            ../C/bin/swdft.obj

        % Link ZCPA on UNIX
        disp('Linking mx_zcpa_run.c ...');
        mex -outdir bin -Isrc -I../C/src src/mx_zcpa_run.c ...
            bin/mx_read.obj bin/mx_write.obj bin/mx_zcpa.obj ...
            ../C/bin/zcpa.obj
        
        % Link IFRH on UNIX
        disp('Linking mx_ifrh_run.c ...');
        mex -outdir bin -Isrc -I../C/src src/mx_ifrh_run.c ...
            bin/mx_read.obj bin/mx_write.obj bin/mx_ifrh.obj ...
            ../C/bin/ifrh.obj
        
    end

    % Compile succeeded: Print a happy message
    disp('Done.');

catch %#ok

    % Compile failed: Print an error message
    error('Could not compile code base.');

end

% Restore working directory
cd(storedpath);

% end of file %
