/* mx_read.h */

/* Support for data conversions from Matlab to C.
 * Author: Robert Mill <rob.mill.uk@gmail.com>
 * (C)2015 University of Sheffield
 */

#ifndef MX_READ_H_INCLUDED
#define MX_READ_H_INCLUDED


/* INCLUDE HEADERS */

#include <mex.h>


/* FUNCTION PROTOTYPES */

int MXR_IsError( void );

void MXR_ClearError( void );

void MXR_SetError( const char *cp_msg );

char * MXR_GetError( void );

const mxArray * MXR_CheckType(
    const mxArray *mp_array,
    const char *cp_name,
    const char *cp_class );

const mxArray * MXR_CheckDims(
    const mxArray *mp_array,
    const char *cp_name,
    int n_row, 
    int n_col );

const mxArray * MXR_CheckComplex(
    const mxArray *mp_array,
    const char *cp_name );

const mxArray * MXR_GetField(
    const mxArray *mp_struct,
    const char *cp_field,
    int n_index );

const int * MXR_GetInt32Ptr(
    const mxArray *mp_struct,
    const char *cp_field,
    int n_index );

const double * MXR_GetDoublePtr(
    const mxArray *mp_struct,
    const char *cp_field, 
    int n_index );

const double * MXR_GetRealPtr(
    const mxArray *mp_struct,
    const char *cp_field, 
    int n_index );

const double * MXR_GetImagPtr(
    const mxArray *mp_struct,
    const char *cp_field,
    int n_index );

int MXR_GetNumEl(
    const mxArray *mp_struct,
    const char *cp_field,
    int n_index );

void MXR_GetInt32(
    const mxArray *mp_struct,
    const char *cp_field, 
    int n_index,
    int n_numel,
    int *np_dest );

void MXR_GetDouble(
    const mxArray *mp_struct,
    const char *cp_field, 
    int n_index,
    int n_numel, 
    double *dp_dest );

void MXR_GetComplex(
    const mxArray *mp_struct,
    const char *cp_field, 
    int n_index,
    int n_numel,
    double *dp_dest_re, 
    double *dp_dest_im );

#endif

/* end of file */
