/* mx_write.c */

/* Support for data conversions from C to Matlab.
 * Author: Robert Mill <rob.mill.uk@gmail.com>
 * (C)2015 University of Sheffield
 */

/* INCLUDER HEADERS */

#include <stdio.h>
#include <string.h>
#include "mx_write.h"


/* CONSTANTS */

enum {N_ERR_MSG_LEN = 255};


/* GLOBAL VARIABLES */

static char cp_error_msg[N_ERR_MSG_LEN + 1];


/* FUNCTION DEFINITIONS */

int MXW_IsError( void )
{
    return cp_error_msg[0] != (char) 0;
}


void MXW_ClearError( void )
{
    cp_error_msg[0] = '\0';
    cp_error_msg[N_ERR_MSG_LEN] = '\0';
}


void MXW_SetError( const char *cp_msg )
{
    strncpy( cp_error_msg, cp_msg, N_ERR_MSG_LEN );
}


char * MXW_GetError( void )
{
    return cp_error_msg;
}


void MXW_PutInt32(
    mxArray *mp_struct,
    const char *cp_field,
    const int *np_data,
    int n_row,
    int n_col )
{
    int n_field = mxAddField( mp_struct, cp_field );

    if( n_field == -1 )
    {
        MXW_SetError( "Could not create field." );
    }
    else
    {
        mxArray *mp_data = mxCreateNumericMatrix(
            n_row,
            n_col,
            mxINT32_CLASS,
            mxREAL );

        if( mp_data != NULL )
        {
            memcpy(
                mxGetPr( mp_data ),
                np_data,
                n_row * n_col * sizeof(int) );

            mxSetFieldByNumber( mp_struct, 0, n_field, mp_data );
        }
    }
}


void MXW_PutDouble(
    mxArray *mp_struct,
    const char *cp_field,
    const double *dp_data,
    int n_row,
    int n_col )
{
    int n_field = mxAddField( mp_struct, cp_field );

    if( n_field == -1 )
    {
        MXW_SetError( "Could not create field." );
    }
    else
    {
        mxArray *mp_data = mxCreateDoubleMatrix( n_row, n_col, mxREAL );

        if( mp_data != NULL )
        {
            memcpy(
                mxGetPr( mp_data ),
                dp_data,
                n_row * n_col * sizeof(double) );

            mxSetFieldByNumber( mp_struct, 0, n_field, mp_data );
        }
    }
}


void MXW_PutComplex(
    mxArray *mp_struct,
    const char *cp_field,
    const double *dp_data_re,
    const double *dp_data_im,
    int n_row,
    int n_col )
{
    int n_field = mxAddField( mp_struct, cp_field );

    if( n_field == -1 )
    {
        MXW_SetError( "Could not create field." );
    }
    else
    {
        mxArray *mp_data = mxCreateDoubleMatrix( n_row, n_col, mxCOMPLEX );

        if( mp_data != NULL )
        {
            memcpy(
                mxGetPr( mp_data ),
                dp_data_re,
                n_row * n_col * sizeof(double) );

            memcpy(
                mxGetPi( mp_data ),
                dp_data_im,
                n_row * n_col * sizeof(double) );

            mxSetFieldByNumber( mp_struct, 0, n_field, mp_data );
        }
    }
}

/* end of file */
